@@ -5,8 +5,8 @@ use std::fs;
 use std::error::Error;
 
 fn run() -> Result<(), Box<dyn Error>> {
-    let path_string = env::args().nth(1).ok_or("usage: tpng <img_path>")?;
-    let path = fs::canonicalize(PathBuf::from(&path_string))?;
+    let path_arg = env::args().nth(1).ok_or("usage: tpng <img_path>")?;
+    let path = fs::canonicalize(PathBuf::from(&path_arg))?;
     println!("{}", Image::new(&path)?);
     Ok(())
 }
